netapp_ontap.models.nvme_subsystem_controller_host API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.nvme_subsystem_controller_host`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class NvmeSubsystemControllerHostSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the NvmeSubsystemControllerHost object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `id GET`

    The host identifier registered with the controller.

    Example: b8546ca6097349e5b1558dc154fc073b

  `nqn GET`

    The NVMe qualified name of the host.

    Example: nqn.2014-08.org.nvmexpress:uuid:c2846cb1-89d2-4020-a3b0-71ce907b4eef

  `transport_address GET`

    The transport address of the host.

    Example: nn-0x20000090fae00806:pn-0x10000090fae00806